from typing import Optional

from .base_http_exception import BaseHttpException


class BadRequestException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(400, message, header)


class UnauthorisedException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(401, message, header)


class ForbiddenException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(403, message, header)


class NotFoundException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(404, message, header)


class TimeoutException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(408, message, header)


class ConflictException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(409, message, header)


class PayloadTooLargeException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(413, message, header)   


from typing import Optional

from .base_http_exception import BaseHttpException


class InternalServerException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(500, message, header)


class NotImplimentedException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(501, message, header)


class BadGatewayException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(502, message, header)


class GatewayTimeoutException(BaseHttpException):

    def __init__(self, message: str, header: Optional[str] = None):
        super().__init__(504, message, header)



from typing import Optional, Union


class BaseHttpException(Exception):

    status_code: int
    message: str
    header: Union[str, None]

    def __init__(self, status_code: int, message: str, header: Optional[str] = None) -> None:
        self.status_code = status_code
        self.message = message
        self.header = header
    
    def __repr__(self) -> str:
        class_name = self.__class__.__name__
        if (self.header is None):
            return f"{class_name}(status_code={self.status_code}, message={self.message})"
        else:
            return f"{class_name}(status_code={self.status_code}, message={self.message}, header={self.header})"



from setuptools import find_packages, setup

setup(name="python_web_exceptions",
      version='1.0',
      description="Framework agnostic web exceptions for python",
      author="Aaron Martin",
      url="https://github.com/ajmar3/python-web-exceptions",
      license="MIT",
      packages=find_packages()
      )

